Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/analysis/abstract_base_classes/confidence_computer_abc.py: 75%

# Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/analysis/abstract_base_classes/confidence_computer_abc.py : 75%

## 16 statements 12 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 | # Copyright 2017-2020 Spotify AB # # Licensed under the Apache License, Version 2.0 (the "License"); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. from abc import ABC, abstractmethod from typing import (Union, Iterable) from pandas import DataFrame from ..constants import NIM_TYPE class ConfidenceComputerABC(ABC): @abstractmethod def compute_summary(self, verbose: bool) -> DataFrame: """Return Pandas DataFrame with summary statistics. """ pass @abstractmethod def compute_difference(self, level_1: Union[str, Iterable], level_2: Union[str, Iterable], absolute: bool, groupby: Union[str, Iterable], nims: NIM_TYPE, final_expected_sample_size_column: str, verbose: bool ) -> DataFrame: """Return dataframe containing the difference in means between group 1 and 2, p-value and confidence interval """ pass @abstractmethod def compute_multiple_difference(self, level: Union[str, Iterable], absolute: bool, groupby: Union[str, Iterable], level_as_reference: bool, nims: NIM_TYPE, mdes: bool, final_expected_sample_size_column: str, verbose: bool ) -> DataFrame: """The pairwise probability that the specific group is greater than all other groups. """ pass def achieved_power(self, level_1: Union[str, Iterable], level_2: Union[str, Iterable], mde: float, alpha: float, groupby: Union[str, Iterable]) -> DataFrame: pass